%%
%% This is file `exampaper.cls',
%% 
%%   ______________________________________
%%   Copyright © 2012  Vafa Khalighi
%% 
%%   License information appended.
%% 
%% 
\NeedsTeXFormat{LaTeX2e}
\ProvidesClass{exampaper}[2012/06/18 v0.1 Typeset Persian exam papers]
\DeclareOption*{\PassOptionsToClass{\CurrentOption}{article}}
\ProcessOptions\relax
\LoadClass{article}
\RequirePackage{geometry,fancyhdr,graphicx,lastpage,keyval}
\geometry{a4paper,top=4cm,bottom=3cm,left=3cm,right=3cm}
\pagestyle{fancy}
\fancyhead{}{}
\fancyfoot{}{}
\lhead{درس: \exampaper@courseid{} \exampaper@coursename}
\rhead{صفحه~\thepage~از~\pageref{LastPage}}
\cfoot{\exampaper@nextpagetext}
\newif\ifexampaper@answers
\newif\ifexampaper@supplementary


\def\exampaper@boolkey#1#2{%
  \csname exampaper@#2\ifx\relax#1\relax true\else#1\fi\endcsname}

\define@key{exampaper}{answers}[true]{\exampaper@boolkey{#1}{answers}}
\define@key{exampaper}{supplementary}[true]{\exampaper@boolkey{#1}{supplementary}}

\define@key{exampaper}{teaching period}{\def\exampaper@semester{#1}}
\define@key{exampaper}{year}{\def\exampaper@year{#1}}
\define@key{exampaper}{course name}{\def\exampaper@coursename{#1}}
\define@key{exampaper}{course id}{\def\exampaper@courseid{#1}}
\define@key{exampaper}{degree type}{\def\exampaper@degreetype{#1}}
\define@key{exampaper}{degree name}{\def\exampaper@degreename{#1}}
\define@key{exampaper}{exam time}{\def\exampaper@examtime{#1}}



\AtBeginDocument{%
\ifexampaper@answers%
  \newcommand\answer[1]{\par{\iranicfamily\ignorespaces #1\unskip\par}}
  \newcommand\exampaper@nextpagetext{}
\else
  \newcommand\exampaper@nextpagetext{%
    \ifdefined\r@LastPage
      \ifnum \c@page = \expandafter\@secondoftwo\r@LastPage \relax
        پایان امتحان%
      \else
        لطفاً صفحه بعد را ببینید%
      \fi
    \else
      \ClassWarning{exampaper}{Please re-run xelatex!}%
    \fi
  }  
  \newcommand\answer[1]{}
\fi}

\newcommand\totalmarks{%
  \bigskip\noindent
  \addtocounter{totalmarks}{\value{marks}}%
  \stepcounter{Nparts}%
  \textbf{جمع نمرات: \arabic{marks}.}%
  \newcounter{markedpart:\theNparts}
  \setcounter{markedpart:\theNparts}{\numexpr\value{marks}-1\relax}
  \refstepcounter{markedpart:\theNparts}
  \label{markedpart:\theNparts}
  \setcounter{marks}{0}
}

\def\countmarks{
%  \addtocounter{totalmarks}{-1}
  \refstepcounter{totalmarks}
  \label{marks:total}
  
  \addtocounter{Nparts}{-1}
  \refstepcounter{Nparts}
  \label{parts:total}
}

\newcounter{totalmarks}
\newcounter{Nparts}

\newcounter{marks}


\newcommand\exampapersetup{\setkeys{exampaper}}

\newcommand\Marks[1]{\addtocounter{marks}{#1}\hfill\penalty100\hspace*{\fill}\textbf{\fontsize{9}{9}\selectfont [#1~ نمره]}\ignorespaces}

\newenvironment{coverpage}{
  \begin{titlepage}
  \setlength\parindent{0pt}
  
  \centerline{%
    \IfFileExists{uni-logo.pdf}{\includegraphics{uni-logo}}{%
      \ClassWarning{exampaper}{Logo missing. Download the university logo and call it uni-logo.pdf}%
    }
  }
  
  \bigskip
  
  \begin{center}
  \large
  \bfseries
  \centerline{%
  امتحان
\ifexampaper@supplementary
    جبرانی
  \fi
   درجه \exampaper@degreetype{} رشته \exampaper@degreename}
  \bigskip
  \exampaper@semester, \exampaper@year
  \end{center}
  
  \bigskip
  
  \centerline{\fbox{\parbox{\linewidth}{\large\bfseries
نام  درس:
   \exampaper@coursename\\
  کد درس: \exampaper@courseid
  }}}
  
  \bigskip
  
  \ifexampaper@answers
  \centerline{\Huge\bfseries جواب‌ها}
  \bigskip
  \fi
  
  \begin{flushright}
  \begin{tabular}{@{}rr}
  زمان خواندن: & ۱۰ دقیقه\\
  زمان نوشتن:& 
  \exampaper@examtime{} دقیقه\\
  زمان کل: &
   \the\numexpr \exampaper@examtime+10\relax\ دقیقه
  \end{tabular}
  \end{flushright}
  
  \bigskip
  
  


\let\@tempa\@empty

\ifcsname r@parts:total\endcsname

\@tempcnta=1\relax
\loop
  \edef\@tempb{
    \the\@tempcnta & 
    به تمام سوالات جواب دهید & 
    \unexpanded{\the\numexpr}
    \exampaper@examtime*\expandafter\expandafter\expandafter\@firstoftwo\csname r@markedpart:\the\@tempcnta\endcsname    
    /\expandafter\expandafter\expandafter\@firstoftwo\csname r@marks:total\endcsname
    \relax\
    دقیقه & 
    \noexpand\ref{markedpart:\the\@tempcnta} نمره \noexpand
    \\}
  \expandafter\g@addto@macro\expandafter\@tempa\expandafter{\@tempb}

  \advance\@tempcnta by 1\relax
\ifnum\@tempcnta <
  \expandafter\expandafter\expandafter
    \@secondoftwo\csname r@parts:total\endcsname
\repeat

\fi

\begin{center}
\begin{tabular}{@{}rrrr}
\bfseries بخش & \bfseries سوالات & \bfseries زمان تقریبی & \bfseries نمرات \\
\@tempa
\cline{4-4}
& & &
جمع
 \ref{marks:total} 
\end{tabular}
\end{center}

\bigskip
}{
  \vfill
  \centerline{تا زمانی که اعلام نشده، شروع به نوشتن نکنید}
  \end{titlepage}
  \stepcounter{page}
}

%% 
%% Copyright © 2012  Vafa Khalighi <vafakhlg@gmail.com>
%% 
%% It may be distributed and/or modified under the LaTeX Project Public License,
%% version 1.3c or higher (your choice). The latest version of
%% this license is at: http://www.latex-project.org/lppl.txt
%% 
%% This work is “author-maintained” (as per LPPL maintenance status)
%% by Vafa Khalighi.
%% 
%% 
%% 
%%
%% End of file `exampaper.cls'.